@@ -1,3 +1,4 @@
+// Return the first index, if any, where the given byte occurs.
 #[must_use]
 pub const fn find(slice: &[u8], elem: u8) -> Option<usize> {
     let mut idx = 0;
@@ -12,14 +13,22 @@ pub const fn find(slice: &[u8], elem: u8) -> Option<usize> {
     }
 }
 
+// Return true if the slice contains a single NUL byte in the last position of
+// the slice.
 #[must_use]
 pub const fn is_cstr(slice: &[u8]) -> bool {
     matches!(find(slice, 0), Some(nul_pos) if nul_pos + 1 == slice.len())
 }
 
+// Returns true if the slice contains any NUL bytes.
+#[must_use]
+pub const fn contains_nul(slice: &[u8]) -> bool {
+    matches!(find(slice, 0), Some(_))
+}
+
 #[cfg(test)]
 mod tests {
-    use super::{find, is_cstr};
+    use super::{contains_nul, find, is_cstr};
 
     #[test]
     fn find_nul_byte() {
@@ -52,4 +61,20 @@ mod tests {
         assert!(is_cstr(b"abc\0"));
         assert!(is_cstr(b"abc\xFFxyz\0"));
     }
+
+    #[test]
+    fn check_contains_nul_byte() {
+        assert!(!contains_nul(b""));
+        assert!(!contains_nul(b"abc"));
+        assert!(!contains_nul(b"abc\xFFxyz"));
+
+        assert!(contains_nul(b"abc\0xyz"));
+        assert!(contains_nul(b"abc\0xyz\0"));
+        assert!(contains_nul(b"abc\xFF\0xyz"));
+        assert!(contains_nul(b"abc\xFF\0xyz\0"));
+
+        assert!(contains_nul(b"\0"));
+        assert!(contains_nul(b"abc\0"));
+        assert!(contains_nul(b"abc\xFFxyz\0"));
+    }
 }
